==> haskell-cborg-json-0.2.6.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-LyCvBHVjBUQB2qzvfM0p5L
key:                  cborg-json-0.2.6.0-LyCvBHVjBUQB2qzvfM0p5L
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  fdcf6ff3fa6ef5984ecabc03f9b0c925
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-LyCvBHVjBUQB2qzvfM0p5L
depends:
    aeson-2.1.2.1-9HQxGJjc2cdAmcsURaBDXL
    aeson-pretty-0.8.10-HYo4weCPLstKhfbybgCGjY base-4.17.2.1
    base64-bytestring-1.2.1.0-Jr4dnoqop9Z6dS9yQYn7ws
    cborg-0.2.10.0-C8hBLaZGqsJ4EF87wxCr8Z
    scientific-0.3.8.0-3yGVBVyv6Qa6KG5OKC2ZxZ text-2.0.2
    unordered-containers-0.2.20-3czZ5Len2GTFaAkRxFZe7E
    vector-0.13.2.0-GTax7SJDHXyLP8P6Lzhygl

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cborg-json-0.2.6.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-13INRkcB8FoGFGuaocnEDq
key:                  cborg-json-0.2.6.0-13INRkcB8FoGFGuaocnEDq
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  296d31f19eabefaeb494664377460139
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-13INRkcB8FoGFGuaocnEDq
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh
    aeson-pretty-0.8.10-HWmn7v7pElT331cgWAs6cN base-4.17.2.1
    base64-bytestring-1.2.1.0-7XHgmf0PZMy7LO91awCYGH
    cborg-0.2.10.0-CRAHniDpPicH1m0DFqhKeC
    scientific-0.3.8.0-HUqAf4XaF5T5GawpMI5GwR text-2.0.2
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
